@@ -25,12 +25,11 @@ def load_environment_variables():
     with open(absolute_config_file) as file:
         yaml_config = yaml.safe_load(file.read())
 
-    with open(yaml_config["cloud"]["key_file"]) as file:
-        key_file = json.loads(file.read())
-
-    os.environ["SERVICE_ACCOUNT_EMAIL"] = key_file["client_email"]
     os.environ["CLOUD_FUNCTIONS_SERVICE_ACCOUNT_EMAIL"] = yaml_config["cloud"]["cloud_functions_service_account"]
 
+    os.environ["TERRAFORM_ORGANIZATION"] = yaml_config["terraform"]["organization"]
+    os.environ["TERRAFORM_WORKSPACE"] = yaml_config["terraform"]["workspace"]
+
 
 @cli.command("init")
 def init():
@@ -51,7 +50,6 @@ def init():
         "provider": {
             yaml_config["cloud"]["provider"]:
                 {
-                    "credentials": os.path.abspath(yaml_config["cloud"]["key_file"]),
                     "project": yaml_config["cloud"]["project"],
                     "region": yaml_config["cloud"]["region"]
                 }
@@ -62,6 +60,16 @@ def init():
                     "name": yaml_config["cloud"]["default_bucket"]
                 }
             }
+        },
+        "terraform": {
+            "backend": {
+                "remote": {
+                    "organization": os.environ["TERRAFORM_ORGANIZATION"],
+                    "workspaces": {
+                        "name": os.environ["TERRAFORM_WORKSPACE"]
+                    }
+                }
+            }
         }
     }
 
@@ -69,9 +77,7 @@ def init():
     with open(provider_config,"w") as file:
         file.write(json.dumps(config, indent=4, sort_keys=False))
 
-    print(subprocess.call(["terraform", "init"], cwd="terraform_plan"))
-
-    print("Limber has now successfully initialized using your configuration using Terraform")
+    print("Limber has now successfully initialized using your configuration")
 
 t = terraform(folder="terraform_plan")
 
@@ -81,23 +87,6 @@ def plan():
     Create a plan for infra
     """
     t.create_terraform_configuration()
-    print(subprocess.call(["terraform", "plan"], cwd="terraform_plan"))
-
-@cli.command("apply")
-def apply():
-    print(subprocess.call(["terraform", "apply"], cwd="terraform_plan"))
-
-
-@cli.group()
-def terraform():
-    """
-    Commands related to Terraform
-    """
-
-@terraform.command("login")
-def login():
-    print("Using the Terraform CLI to login")
-    print(subprocess.call(["terraform", "login"]))
 
 
 if __name__ == '__main__':
